@@ -1,4 +1,4 @@
-// Copyright 2017 The Hugo Authors. All rights reserved.
+// Copyright 2018 The Hugo Authors. All rights reserved.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -17,6 +17,9 @@ import (
 	"os"
 	"path/filepath"
 	"sync"
+	"time"
+
+	"github.com/gohugoio/hugo/config"
 
 	"github.com/spf13/cobra"
 
@@ -26,6 +29,7 @@ import (
 
 	"github.com/gohugoio/hugo/hugolib"
 
+	"github.com/bep/debounce"
 	"github.com/gohugoio/hugo/common/types"
 	"github.com/gohugoio/hugo/deps"
 	"github.com/gohugoio/hugo/helpers"
@@ -36,7 +40,10 @@ import (
 type commandeer struct {
 	*deps.DepsCfg
 
-	subCmdVs []*cobra.Command
+	hugo *hugolib.HugoSites
+
+	h    *hugoBuilderCommon
+	ftch flagsToConfigHandler
 
 	pathSpec    *helpers.PathSpec
 	visitedURLs *types.EvictingStringQueue
@@ -51,8 +58,12 @@ type commandeer struct {
 	// We can do this only once.
 	fsCreate sync.Once
 
-	serverPorts []int
-	languages   helpers.Languages
+	// Used in cases where we get flooded with events in server mode.
+	debounce func(f func())
+
+	serverPorts         []int
+	languagesConfigured bool
+	languages           helpers.Languages
 
 	configured bool
 }
@@ -88,12 +99,23 @@ func (c *commandeer) initFs(fs *hugofs.Fs) error {
 	return nil
 }
 
-func newCommandeer(running bool, doWithCommandeer func(c *commandeer) error, subCmdVs ...*cobra.Command) (*commandeer, error) {
+func newCommandeer(running bool, h *hugoBuilderCommon, f flagsToConfigHandler, doWithCommandeer func(c *commandeer) error, subCmdVs ...*cobra.Command) (*commandeer, error) {
+
+	var rebuildDebouncer func(f func())
+	if running {
+		// The time value used is tested with mass content replacements in a fairly big Hugo site.
+		// It is better to wait for some seconds in those cases rather than get flooded
+		// with rebuilds.
+		rebuildDebouncer, _, _ = debounce.New(4 * time.Second)
+	}
 
 	c := &commandeer{
+		h:                h,
+		ftch:             f,
 		doWithCommandeer: doWithCommandeer,
-		subCmdVs:         append([]*cobra.Command{hugoCmdV}, subCmdVs...),
-		visitedURLs:      types.NewEvictingStringQueue(10)}
+		visitedURLs:      types.NewEvictingStringQueue(10),
+		debounce:         rebuildDebouncer,
+	}
 
 	return c, c.loadConfig(running)
 }
@@ -109,8 +131,8 @@ func (c *commandeer) loadConfig(running bool) error {
 	cfg.Running = running
 
 	var dir string
-	if source != "" {
-		dir, _ = filepath.Abs(source)
+	if c.h.source != "" {
+		dir, _ = filepath.Abs(c.h.source)
 	} else {
 		dir, _ = os.Getwd()
 	}
@@ -120,73 +142,57 @@ func (c *commandeer) loadConfig(running bool) error {
 		sourceFs = c.DepsCfg.Fs.Source
 	}
 
-	config, configFiles, err := hugolib.LoadConfig(hugolib.ConfigSourceDescriptor{Fs: sourceFs, Path: source, WorkingDir: dir, Filename: cfgFile})
+	doWithConfig := func(cfg config.Provider) error {
+
+		if c.ftch != nil {
+			c.ftch.flagsToConfig(cfg)
+		}
+
+		cfg.Set("workingDir", dir)
+
+		return nil
+	}
+
+	doWithCommandeer := func(cfg config.Provider) error {
+		c.Cfg = cfg
+		if c.doWithCommandeer == nil {
+			return nil
+		}
+		err := c.doWithCommandeer(c)
+		return err
+	}
+
+	config, configFiles, err := hugolib.LoadConfig(
+		hugolib.ConfigSourceDescriptor{Fs: sourceFs, Path: c.h.source, WorkingDir: dir, Filename: c.h.cfgFile},
+		doWithCommandeer,
+		doWithConfig)
+
 	if err != nil {
 		return err
 	}
 
-	c.Cfg = config
 	c.configFiles = configFiles
 
-	for _, cmdV := range c.subCmdVs {
-		c.initializeFlags(cmdV)
-	}
-
 	if l, ok := c.Cfg.Get("languagesSorted").(helpers.Languages); ok {
+		c.languagesConfigured = true
 		c.languages = l
 	}
 
-	if baseURL != "" {
-		config.Set("baseURL", baseURL)
-	}
-
+	// This is potentially double work, but we need to do this one more time now
+	// that all the languages have been configured.
 	if c.doWithCommandeer != nil {
-		err = c.doWithCommandeer(c)
+		if err := c.doWithCommandeer(c); err != nil {
+			return err
+		}
 	}
 
-	if err != nil {
-		return err
-	}
-
-	if len(disableKinds) > 0 {
-		c.Set("disableKinds", disableKinds)
-	}
-
-	logger, err := createLogger(cfg.Cfg)
+	logger, err := c.createLogger(config)
 	if err != nil {
 		return err
 	}
 
 	cfg.Logger = logger
 
-	config.Set("logI18nWarnings", logI18nWarnings)
-
-	if theme != "" {
-		config.Set("theme", theme)
-	}
-
-	if themesDir != "" {
-		config.Set("themesDir", themesDir)
-	}
-
-	if destination != "" {
-		config.Set("publishDir", destination)
-	}
-
-	config.Set("workingDir", dir)
-
-	if contentDir != "" {
-		config.Set("contentDir", contentDir)
-	}
-
-	if layoutDir != "" {
-		config.Set("layoutDir", layoutDir)
-	}
-
-	if cacheDir != "" {
-		config.Set("cacheDir", cacheDir)
-	}
-
 	createMemFs := config.GetBool("renderToMemory")
 
 	if createMemFs {
@@ -209,7 +215,7 @@ func (c *commandeer) loadConfig(running bool) error {
 		return err
 	}
 
-	cacheDir = config.GetString("cacheDir")
+	cacheDir := config.GetString("cacheDir")
 	if cacheDir != "" {
 		if helpers.FilePathSeparator != cacheDir[len(cacheDir)-1:] {
 			cacheDir = cacheDir + helpers.FilePathSeparator
