@@ -17,11 +17,10 @@ import (
 	"fmt"
 	"net/url"
 	"path"
+	"path/filepath"
 	"strings"
 
 	"github.com/PuerkitoBio/purell"
-	jww "github.com/spf13/jwalterweatherman"
-	"github.com/spf13/viper"
 )
 
 type pathBridge struct {
@@ -103,10 +102,20 @@ func SanitizeURLKeepTrailingSlash(in string) string {
 //     uri: Vim (text editor)
 //     urlize: vim-text-editor
 func (p *PathSpec) URLize(uri string) string {
-	sanitized := p.MakePathSanitized(uri)
+	return p.URLEscape(p.MakePathSanitized(uri))
 
+}
+
+// URLizeFilename creates an URL from a filename by esacaping unicode letters
+// and turn any filepath separator into forward slashes.
+func (p *PathSpec) URLizeFilename(filename string) string {
+	return p.URLEscape(filepath.ToSlash(filename))
+}
+
+// URLEscape escapes unicode letters.
+func (p *PathSpec) URLEscape(uri string) string {
 	// escape unicode letters
-	parsedURI, err := url.Parse(sanitized)
+	parsedURI, err := url.Parse(uri)
 	if err != nil {
 		// if net/url can not parse URL it means Sanitize works incorrectly
 		panic(err)
@@ -147,7 +156,7 @@ func MakePermalink(host, plink string) *url.URL {
 	return base
 }
 
-// AbsURL creates a absolute URL from the relative path given and the BaseURL set in config.
+// AbsURL creates an absolute URL from the relative path given and the BaseURL set in config.
 func (p *PathSpec) AbsURL(in string, addLanguage bool) string {
 	url, err := url.Parse(in)
 	if err != nil {
@@ -158,14 +167,13 @@ func (p *PathSpec) AbsURL(in string, addLanguage bool) string {
 		return in
 	}
 
-	baseURL := viper.GetString("baseURL")
+	var baseURL string
 	if strings.HasPrefix(in, "/") {
-		p, err := url.Parse(baseURL)
-		if err != nil {
-			panic(err)
-		}
-		p.Path = ""
-		baseURL = p.String()
+		u := p.BaseURL.URL()
+		u.Path = ""
+		baseURL = u.String()
+	} else {
+		baseURL = p.BaseURL.String()
 	}
 
 	if addLanguage {
@@ -200,13 +208,30 @@ func (p *PathSpec) getLanguagePrefix() string {
 	defaultLang := p.defaultContentLanguage
 	defaultInSubDir := p.defaultContentLanguageInSubdir
 
-	currentLang := p.currentContentLanguage.Lang
+	currentLang := p.Language.Lang
 	if currentLang == "" || (currentLang == defaultLang && !defaultInSubDir) {
 		return ""
 	}
 	return currentLang
 }
 
+// GetLangSubDir returns the given language's subdir if needed.
+func (p *PathSpec) GetLangSubDir(lang string) string {
+	if !p.multilingual {
+		return ""
+	}
+
+	if p.Languages.IsMultihost() {
+		return ""
+	}
+
+	if lang == "" || (lang == p.defaultContentLanguage && !p.defaultContentLanguageInSubdir) {
+		return ""
+	}
+
+	return lang
+}
+
 // IsAbsURL determines whether the given path points to an absolute URL.
 func IsAbsURL(path string) bool {
 	url, err := url.Parse(path)
@@ -220,7 +245,7 @@ func IsAbsURL(path string) bool {
 // RelURL creates a URL relative to the BaseURL root.
 // Note: The result URL will not include the context root if canonifyURLs is enabled.
 func (p *PathSpec) RelURL(in string, addLanguage bool) string {
-	baseURL := viper.GetString("baseURL")
+	baseURL := p.BaseURL.String()
 	canonifyURLs := p.canonifyURLs
 	if (!strings.HasPrefix(in, baseURL) && strings.HasPrefix(in, "http")) || strings.HasPrefix(in, "//") {
 		return in
@@ -289,6 +314,23 @@ func AddContextRoot(baseURL, relativePath string) string {
 	return newPath
 }
 
+// PrependBasePath prepends any baseURL sub-folder to the given resource
+// if canonifyURLs is disabled.
+// If canonifyURLs is set, we will globally prepend the absURL with any sub-folder,
+// so avoid doing anything here to avoid getting double paths.
+func (p *PathSpec) PrependBasePath(rel string) string {
+	if p.BasePath != "" {
+		rel = filepath.ToSlash(rel)
+		// Need to prepend any path from the baseURL
+		hadSlash := strings.HasSuffix(rel, "/")
+		rel = path.Join(p.BasePath, rel)
+		if hadSlash {
+			rel += "/"
+		}
+	}
+	return rel
+}
+
 // URLizeAndPrep applies misc sanitation to the given URL to get it in line
 // with the Hugo standard.
 func (p *PathSpec) URLizeAndPrep(in string) string {
@@ -298,17 +340,15 @@ func (p *PathSpec) URLizeAndPrep(in string) string {
 // URLPrep applies misc sanitation to the given URL.
 func (p *PathSpec) URLPrep(in string) string {
 	if p.uglyURLs {
-		x := Uglify(SanitizeURL(in))
-		return x
+		return Uglify(SanitizeURL(in))
 	}
-	x := PrettifyURL(SanitizeURL(in))
-	if path.Ext(x) == ".xml" {
-		return x
+	pretty := PrettifyURL(SanitizeURL(in))
+	if path.Ext(pretty) == ".xml" {
+		return pretty
 	}
-	url, err := purell.NormalizeURLString(x, purell.FlagAddTrailingSlash)
+	url, err := purell.NormalizeURLString(pretty, purell.FlagAddTrailingSlash)
 	if err != nil {
-		jww.ERROR.Printf("Failed to normalize URL string. Returning in = %q\n", in)
-		return in
+		return pretty
 	}
 	return url
 }
