@@ -1,21 +1,21 @@
 package hugolib
 
 import (
-	"path/filepath"
 	"testing"
 
-	"github.com/spf13/afero"
 	"github.com/stretchr/testify/require"
 )
 
 func TestMultihosts(t *testing.T) {
 	t.Parallel()
 
-	var multiSiteTOMLConfigTemplate = `
+	assert := require.New(t)
+
+	var configTemplate = `
 paginate = 1
 disablePathToLower = true
-defaultContentLanguage = "{{ .DefaultContentLanguage }}"
-defaultContentLanguageInSubdir = {{ .DefaultContentLanguageInSubdir }}
+defaultContentLanguage = "fr"
+defaultContentLanguageInSubdir = false
 staticDir = ["s1", "s2"]
 
 [permalinks]
@@ -48,18 +48,12 @@ languageName = "Nynorsk"
 
 `
 
-	siteConfig := testSiteConfig{Running: true, Fs: afero.NewMemMapFs(), DefaultContentLanguage: "fr", DefaultContentLanguageInSubdir: false}
-	sites := createMultiTestSites(t, siteConfig, multiSiteTOMLConfigTemplate)
-	fs := sites.Fs
-	th := testHelper{sites.Cfg, fs, t}
-	assert := require.New(t)
-	cfg := BuildCfg{}
-	err := sites.Build(cfg)
-	assert.NoError(err)
+	b := newMultiSiteTestDefaultBuilder(t).WithConfigFile("toml", configTemplate)
+	b.CreateSites().Build(BuildCfg{})
 
-	th.assertFileContent("public/en/sect/doc1-slug/index.html", "Hello")
+	b.AssertFileContent("public/en/sect/doc1-slug/index.html", "Hello")
 
-	s1 := sites.Sites[0]
+	s1 := b.H.Sites[0]
 
 	assert.Equal([]string{"s1", "s2", "ens1", "ens2"}, s1.StaticDirs())
 
@@ -78,26 +72,26 @@ languageName = "Nynorsk"
 	assert.NotNil(pageWithURLInFrontMatter)
 	assert.Equal("/superbob", pageWithURLInFrontMatter.URL())
 	assert.Equal("/docs/superbob/", pageWithURLInFrontMatter.RelPermalink())
-	th.assertFileContent("public/en/superbob/index.html", "doc3|Hello|en")
+	b.AssertFileContent("public/en/superbob/index.html", "doc3|Hello|en")
 
 	// check alias:
-	th.assertFileContent("public/en/al/alias1/index.html", `content="0; url=https://example.com/docs/superbob/"`)
-	th.assertFileContent("public/en/al/alias2/index.html", `content="0; url=https://example.com/docs/superbob/"`)
+	b.AssertFileContent("public/en/al/alias1/index.html", `content="0; url=https://example.com/docs/superbob/"`)
+	b.AssertFileContent("public/en/al/alias2/index.html", `content="0; url=https://example.com/docs/superbob/"`)
 
-	s2 := sites.Sites[1]
+	s2 := b.H.Sites[1]
 	assert.Equal([]string{"s1", "s2", "frs1", "frs2"}, s2.StaticDirs())
 
 	s2h := s2.getPage(KindHome)
 	assert.Equal("https://example.fr/", s2h.Permalink())
 
-	th.assertFileContentStraight("public/fr/index.html", "French Home Page")
-	th.assertFileContentStraight("public/en/index.html", "Default Home Page")
+	b.AssertFileContent("public/fr/index.html", "French Home Page")
+	b.AssertFileContent("public/en/index.html", "Default Home Page")
 
 	// Check paginators
-	th.assertFileContent("public/en/page/1/index.html", `refresh" content="0; url=https://example.com/docs/"`)
-	th.assertFileContent("public/nn/page/1/index.html", `refresh" content="0; url=https://example.no/"`)
-	th.assertFileContent("public/en/sect/page/2/index.html", "List Page 2", "Hello", "https://example.com/docs/sect/", "\"/docs/sect/page/3/")
-	th.assertFileContent("public/fr/sect/page/2/index.html", "List Page 2", "Bonjour", "https://example.fr/sect/")
+	b.AssertFileContent("public/en/page/1/index.html", `refresh" content="0; url=https://example.com/docs/"`)
+	b.AssertFileContent("public/nn/page/1/index.html", `refresh" content="0; url=https://example.no/"`)
+	b.AssertFileContent("public/en/sect/page/2/index.html", "List Page 2", "Hello", "https://example.com/docs/sect/", "\"/docs/sect/page/3/")
+	b.AssertFileContent("public/fr/sect/page/2/index.html", "List Page 2", "Bonjour", "https://example.fr/sect/")
 
 	// Check bundles
 
@@ -108,7 +102,7 @@ languageName = "Nynorsk"
 	logoEn := bundleEn.Resources.GetByPrefix("logo")
 	require.NotNil(t, logoEn)
 	require.Equal(t, "/docs/bundles/b1/logo.png", logoEn.RelPermalink())
-	require.Contains(t, readFileFromFs(t, fs.Destination, filepath.FromSlash("public/en/bundles/b1/logo.png")), "PNG Data")
+	b.AssertFileContent("public/en/bundles/b1/logo.png", "PNG Data")
 
 	bundleFr := s2.getPage(KindPage, "bundles/b1/index.md")
 	require.NotNil(t, bundleFr)
@@ -117,6 +111,6 @@ languageName = "Nynorsk"
 	logoFr := bundleFr.Resources.GetByPrefix("logo")
 	require.NotNil(t, logoFr)
 	require.Equal(t, "/bundles/b1/logo.png", logoFr.RelPermalink())
-	require.Contains(t, readFileFromFs(t, fs.Destination, filepath.FromSlash("public/fr/bundles/b1/logo.png")), "PNG Data")
+	b.AssertFileContent("public/fr/bundles/b1/logo.png", "PNG Data")
 
 }
