@@ -38,24 +38,26 @@ var pageGroupTestSources = []pageGroupTestObject{
 }
 
 func preparePageGroupTestPages(t *testing.T) Pages {
+	s := newTestSite(t)
 	var pages Pages
-	for _, s := range pageGroupTestSources {
-		p, err := NewPage(filepath.FromSlash(s.path))
+	for _, src := range pageGroupTestSources {
+		p, err := s.NewPage(filepath.FromSlash(src.path))
 		if err != nil {
-			t.Fatalf("failed to prepare test page %s", s.path)
+			t.Fatalf("failed to prepare test page %s", src.path)
 		}
-		p.Weight = s.weight
-		p.Date = cast.ToTime(s.date)
-		p.PublishDate = cast.ToTime(s.date)
-		p.ExpiryDate = cast.ToTime(s.date)
-		p.Params["custom_param"] = s.param
-		p.Params["custom_date"] = cast.ToTime(s.date)
+		p.Weight = src.weight
+		p.Date = cast.ToTime(src.date)
+		p.PublishDate = cast.ToTime(src.date)
+		p.ExpiryDate = cast.ToTime(src.date)
+		p.params["custom_param"] = src.param
+		p.params["custom_date"] = cast.ToTime(src.date)
 		pages = append(pages, p)
 	}
 	return pages
 }
 
 func TestGroupByWithFieldNameArg(t *testing.T) {
+	t.Parallel()
 	pages := preparePageGroupTestPages(t)
 	expect := PagesGroup{
 		{Key: 1, Pages: Pages{pages[3], pages[4]}},
@@ -73,6 +75,7 @@ func TestGroupByWithFieldNameArg(t *testing.T) {
 }
 
 func TestGroupByWithMethodNameArg(t *testing.T) {
+	t.Parallel()
 	pages := preparePageGroupTestPages(t)
 	expect := PagesGroup{
 		{Key: "section1", Pages: Pages{pages[0], pages[1], pages[2]}},
@@ -89,6 +92,7 @@ func TestGroupByWithMethodNameArg(t *testing.T) {
 }
 
 func TestGroupByWithSectionArg(t *testing.T) {
+	t.Parallel()
 	pages := preparePageGroupTestPages(t)
 	expect := PagesGroup{
 		{Key: "section1", Pages: Pages{pages[0], pages[1], pages[2]}},
@@ -105,6 +109,7 @@ func TestGroupByWithSectionArg(t *testing.T) {
 }
 
 func TestGroupByInReverseOrder(t *testing.T) {
+	t.Parallel()
 	pages := preparePageGroupTestPages(t)
 	expect := PagesGroup{
 		{Key: 3, Pages: Pages{pages[0], pages[1]}},
@@ -122,6 +127,7 @@ func TestGroupByInReverseOrder(t *testing.T) {
 }
 
 func TestGroupByCalledWithEmptyPages(t *testing.T) {
+	t.Parallel()
 	var pages Pages
 	groups, err := pages.GroupBy("Weight")
 	if err != nil {
@@ -133,6 +139,7 @@ func TestGroupByCalledWithEmptyPages(t *testing.T) {
 }
 
 func TestGroupByCalledWithUnavailableKey(t *testing.T) {
+	t.Parallel()
 	pages := preparePageGroupTestPages(t)
 	_, err := pages.GroupBy("UnavailableKey")
 	if err == nil {
@@ -157,6 +164,7 @@ func (page *Page) dummyPageMethodReturnTwoValueForTest() (string, string) {
 }
 
 func TestGroupByCalledWithInvalidMethod(t *testing.T) {
+	t.Parallel()
 	var err error
 	pages := preparePageGroupTestPages(t)
 
@@ -182,6 +190,7 @@ func TestGroupByCalledWithInvalidMethod(t *testing.T) {
 }
 
 func TestReverse(t *testing.T) {
+	t.Parallel()
 	pages := preparePageGroupTestPages(t)
 
 	groups1, err := pages.GroupBy("Weight", "desc")
@@ -201,6 +210,7 @@ func TestReverse(t *testing.T) {
 }
 
 func TestGroupByParam(t *testing.T) {
+	t.Parallel()
 	pages := preparePageGroupTestPages(t)
 	expect := PagesGroup{
 		{Key: "bar", Pages: Pages{pages[1], pages[3]}},
@@ -218,6 +228,7 @@ func TestGroupByParam(t *testing.T) {
 }
 
 func TestGroupByParamInReverseOrder(t *testing.T) {
+	t.Parallel()
 	pages := preparePageGroupTestPages(t)
 	expect := PagesGroup{
 		{Key: "foo", Pages: Pages{pages[0], pages[2]}},
@@ -237,11 +248,12 @@ func TestGroupByParamInReverseOrder(t *testing.T) {
 func TestGroupByParamCalledWithCapitalLetterString(t *testing.T) {
 	testStr := "TestString"
 	f := "/section1/test_capital.md"
-	p, err := NewPage(filepath.FromSlash(f))
+	s := newTestSite(t)
+	p, err := s.NewPage(filepath.FromSlash(f))
 	if err != nil {
 		t.Fatalf("failed to prepare test page %s", f)
 	}
-	p.Params["custom_param"] = testStr
+	p.params["custom_param"] = testStr
 	pages := Pages{p}
 
 	groups, err := pages.GroupByParam("custom_param")
@@ -254,10 +266,11 @@ func TestGroupByParamCalledWithCapitalLetterString(t *testing.T) {
 }
 
 func TestGroupByParamCalledWithSomeUnavailableParams(t *testing.T) {
+	t.Parallel()
 	pages := preparePageGroupTestPages(t)
-	delete(pages[1].Params, "custom_param")
-	delete(pages[3].Params, "custom_param")
-	delete(pages[4].Params, "custom_param")
+	delete(pages[1].params, "custom_param")
+	delete(pages[3].params, "custom_param")
+	delete(pages[4].params, "custom_param")
 
 	expect := PagesGroup{
 		{Key: "foo", Pages: Pages{pages[0], pages[2]}},
@@ -273,6 +286,7 @@ func TestGroupByParamCalledWithSomeUnavailableParams(t *testing.T) {
 }
 
 func TestGroupByParamCalledWithEmptyPages(t *testing.T) {
+	t.Parallel()
 	var pages Pages
 	groups, err := pages.GroupByParam("custom_param")
 	if err != nil {
@@ -284,6 +298,7 @@ func TestGroupByParamCalledWithEmptyPages(t *testing.T) {
 }
 
 func TestGroupByParamCalledWithUnavailableParam(t *testing.T) {
+	t.Parallel()
 	pages := preparePageGroupTestPages(t)
 	_, err := pages.GroupByParam("unavailable_param")
 	if err == nil {
@@ -292,6 +307,7 @@ func TestGroupByParamCalledWithUnavailableParam(t *testing.T) {
 }
 
 func TestGroupByDate(t *testing.T) {
+	t.Parallel()
 	pages := preparePageGroupTestPages(t)
 	expect := PagesGroup{
 		{Key: "2012-04", Pages: Pages{pages[4], pages[2], pages[0]}},
@@ -309,6 +325,7 @@ func TestGroupByDate(t *testing.T) {
 }
 
 func TestGroupByDateInReverseOrder(t *testing.T) {
+	t.Parallel()
 	pages := preparePageGroupTestPages(t)
 	expect := PagesGroup{
 		{Key: "2012-01", Pages: Pages{pages[1]}},
@@ -326,6 +343,7 @@ func TestGroupByDateInReverseOrder(t *testing.T) {
 }
 
 func TestGroupByPublishDate(t *testing.T) {
+	t.Parallel()
 	pages := preparePageGroupTestPages(t)
 	expect := PagesGroup{
 		{Key: "2012-04", Pages: Pages{pages[4], pages[2], pages[0]}},
@@ -343,6 +361,7 @@ func TestGroupByPublishDate(t *testing.T) {
 }
 
 func TestGroupByPublishDateInReverseOrder(t *testing.T) {
+	t.Parallel()
 	pages := preparePageGroupTestPages(t)
 	expect := PagesGroup{
 		{Key: "2012-01", Pages: Pages{pages[1]}},
@@ -360,6 +379,7 @@ func TestGroupByPublishDateInReverseOrder(t *testing.T) {
 }
 
 func TestGroupByPublishDateWithEmptyPages(t *testing.T) {
+	t.Parallel()
 	var pages Pages
 	groups, err := pages.GroupByPublishDate("2006-01")
 	if err != nil {
@@ -371,6 +391,7 @@ func TestGroupByPublishDateWithEmptyPages(t *testing.T) {
 }
 
 func TestGroupByExpiryDate(t *testing.T) {
+	t.Parallel()
 	pages := preparePageGroupTestPages(t)
 	expect := PagesGroup{
 		{Key: "2012-04", Pages: Pages{pages[4], pages[2], pages[0]}},
@@ -388,6 +409,7 @@ func TestGroupByExpiryDate(t *testing.T) {
 }
 
 func TestGroupByParamDate(t *testing.T) {
+	t.Parallel()
 	pages := preparePageGroupTestPages(t)
 	expect := PagesGroup{
 		{Key: "2012-04", Pages: Pages{pages[4], pages[2], pages[0]}},
@@ -405,6 +427,7 @@ func TestGroupByParamDate(t *testing.T) {
 }
 
 func TestGroupByParamDateInReverseOrder(t *testing.T) {
+	t.Parallel()
 	pages := preparePageGroupTestPages(t)
 	expect := PagesGroup{
 		{Key: "2012-01", Pages: Pages{pages[1]}},
@@ -422,6 +445,7 @@ func TestGroupByParamDateInReverseOrder(t *testing.T) {
 }
 
 func TestGroupByParamDateWithEmptyPages(t *testing.T) {
+	t.Parallel()
 	var pages Pages
 	groups, err := pages.GroupByParamDate("custom_date", "2006-01")
 	if err != nil {
