@@ -16,16 +16,22 @@ package main
 import (
 	"runtime"
 
-	"github.com/spf13/hugo/commands"
-	jww "github.com/spf13/jwalterweatherman"
 	"os"
+
+	"github.com/gohugoio/hugo/commands"
 )
 
 func main() {
-	runtime.GOMAXPROCS(runtime.NumCPU())
-	commands.Execute()
 
-	if jww.LogCountForLevelsGreaterThanorEqualTo(jww.LevelError) > 0 {
+	runtime.GOMAXPROCS(runtime.NumCPU())
+	resp := commands.Execute(os.Args[1:])
+
+	if resp.Err != nil {
+		if resp.IsUserError() {
+			resp.Cmd.Println("")
+			resp.Cmd.Println(resp.Cmd.UsageString())
+		}
 		os.Exit(-1)
 	}
+
 }
