@@ -24,10 +24,9 @@ import (
 )
 
 type imageCache struct {
-	absPublishDir string
-	absCacheDir   string
-	pathSpec      *helpers.PathSpec
-	mu            sync.RWMutex
+	cacheDir string
+	pathSpec *helpers.PathSpec
+	mu       sync.RWMutex
 
 	store map[string]*Image
 }
@@ -49,10 +48,17 @@ func (c *imageCache) deleteByPrefix(prefix string) {
 	}
 }
 
-func (c *imageCache) getOrCreate(
-	parent *Image, key string, create func(resourceCacheFilename string) (*Image, error)) (*Image, error) {
+func (c *imageCache) clear() {
+	c.mu.Lock()
+	defer c.mu.Unlock()
+	c.store = make(map[string]*Image)
+}
 
-	relTargetFilename := key
+func (c *imageCache) getOrCreate(
+	parent *Image, conf imageConfig, create func(resourceCacheFilename string) (*Image, error)) (*Image, error) {
+
+	relTarget := parent.relTargetPathFromConfig(conf)
+	key := parent.relTargetPathForRel(relTarget.path(), false)
 
 	if c.pathSpec.Language != nil {
 		// Avoid do and store more work than needed. The language versions will in
@@ -75,22 +81,24 @@ func (c *imageCache) getOrCreate(
 	parent.createMu.Lock()
 	defer parent.createMu.Unlock()
 
-	cacheFilename := filepath.Join(c.absCacheDir, key)
+	cacheFilename := filepath.Join(c.cacheDir, key)
 
 	// The definition of this counter is not that we have processed that amount
 	// (e.g. resized etc.), it can be fetched from file cache,
 	//  but the count of processed image variations for this site.
 	c.pathSpec.ProcessingStats.Incr(&c.pathSpec.ProcessingStats.ProcessedImages)
 
-	exists, err := helpers.Exists(cacheFilename, c.pathSpec.Fs.Source)
+	exists, err := helpers.Exists(cacheFilename, c.pathSpec.BaseFs.ResourcesFs)
 	if err != nil {
 		return nil, err
 	}
 
 	if exists {
 		img = parent.clone()
-		img.relTargetPath = relTargetFilename
-		img.absSourceFilename = cacheFilename
+		img.relTargetPath.file = relTarget.file
+		img.sourceFilename = cacheFilename
+		// We have to look resources file system for this.
+		img.overriddenSourceFs = img.spec.BaseFs.ResourcesFs
 	} else {
 		img, err = create(cacheFilename)
 		if err != nil {
@@ -117,8 +125,8 @@ func (c *imageCache) getOrCreate(
 
 }
 
-func newImageCache(ps *helpers.PathSpec, absCacheDir, absPublishDir string) *imageCache {
-	return &imageCache{pathSpec: ps, store: make(map[string]*Image), absCacheDir: absCacheDir, absPublishDir: absPublishDir}
+func newImageCache(ps *helpers.PathSpec, cacheDir string) *imageCache {
+	return &imageCache{pathSpec: ps, store: make(map[string]*Image), cacheDir: cacheDir}
 }
 
 func timeTrack(start time.Time, name string) {
