@@ -76,9 +76,6 @@ type File interface {
 	FileInfo() os.FileInfo
 
 	String() string
-
-	// Deprecated
-	Bytes() []byte
 }
 
 // A ReadableFile is a File that is readable.
@@ -138,12 +135,6 @@ func (fi *FileInfo) FileInfo() os.FileInfo {
 	return fi.fi
 }
 
-func (fi *FileInfo) Bytes() []byte {
-	// Remove in Hugo 0.38
-	helpers.Deprecated("File", "Bytes", "", true)
-	return []byte("")
-}
-
 func (fi *FileInfo) String() string { return fi.BaseFileName() }
 
 // We create a lot of these FileInfo objects, but there are parts of it used only
@@ -204,9 +195,8 @@ func (sp *SourceSpec) NewFileInfo(baseDir, filename string, isLeafBundle bool, f
 		// This is usyally provided by the filesystem. But this FileInfo is also
 		// created in a standalone context when doing "hugo new". This is
 		// an approximate implementation, which is "good enough" in that case.
-		translationBaseName = strings.TrimSuffix(baseName, ext)
-		fileLangExt := filepath.Ext(translationBaseName)
-		translationBaseName = strings.TrimSuffix(translationBaseName, fileLangExt)
+		fileLangExt := filepath.Ext(baseName)
+		translationBaseName = strings.TrimSuffix(baseName, fileLangExt)
 	}
 
 	f := &FileInfo{
