@@ -21,6 +21,8 @@ import (
 	"testing"
 	"time"
 
+	"github.com/gohugoio/hugo/helpers"
+
 	"github.com/spf13/cast"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
@@ -171,6 +173,17 @@ func doTestCompare(t *testing.T, tp tstCompareType, funcUnderTest func(a, b inte
 		{tstEqerType1("a"), tstEqerType2("a"), 0},
 		{tstEqerType2("a"), tstEqerType1("a"), 0},
 		{tstEqerType2("a"), tstEqerType1("b"), -1},
+		{helpers.MustParseHugoVersion("0.32.1").Version(), helpers.MustParseHugoVersion("0.32").Version(), 1},
+		{helpers.MustParseHugoVersion("0.35").Version(), helpers.MustParseHugoVersion("0.32").Version(), 1},
+		{helpers.MustParseHugoVersion("0.36").Version(), helpers.MustParseHugoVersion("0.36").Version(), 0},
+		{helpers.MustParseHugoVersion("0.32").Version(), helpers.MustParseHugoVersion("0.36").Version(), -1},
+		{helpers.MustParseHugoVersion("0.32").Version(), "0.36", -1},
+		{"0.36", helpers.MustParseHugoVersion("0.32").Version(), 1},
+		{"0.36", helpers.MustParseHugoVersion("0.36").Version(), 0},
+		{"0.37", helpers.MustParseHugoVersion("0.37-DEV").Version(), 1},
+		{"0.37-DEV", helpers.MustParseHugoVersion("0.37").Version(), -1},
+		{"0.36", helpers.MustParseHugoVersion("0.37-DEV").Version(), -1},
+		{"0.37-DEV", helpers.MustParseHugoVersion("0.37-DEV").Version(), 0},
 	} {
 		result := funcUnderTest(test.left, test.right)
 		success := false
