@@ -19,7 +19,7 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/spf13/hugo/helpers"
+	"github.com/gohugoio/hugo/helpers"
 	"github.com/stretchr/testify/assert"
 )
 
