@@ -18,8 +18,6 @@ import (
 	"fmt"
 	"strings"
 	"testing"
-
-	"github.com/spf13/viper"
 )
 
 func TestLiveReloadInject(t *testing.T) {
@@ -28,11 +26,10 @@ func TestLiveReloadInject(t *testing.T) {
 }
 
 func doTestLiveReloadInject(t *testing.T, bodyEndTag string) {
-	viper.Set("port", 1313)
 	out := new(bytes.Buffer)
 	in := strings.NewReader(bodyEndTag)
 
-	tr := NewChain(LiveReloadInject)
+	tr := NewChain(LiveReloadInject(1313))
 	tr.Apply(out, in, []byte("path"))
 
 	expected := fmt.Sprintf(`<script data-no-instant>document.write('<script src="/livereload.js?port=1313&mindelay=10"></' + 'script>')</script>%s`, bodyEndTag)
